@@ -61,6 +61,9 @@ esm_destroy (GtkObject *object)
 	esm = E_SELECTION_MODEL (object);
 
 	drop_sorter(esm);
+
+	if (e_selection_model_parent_class->destroy)
+		(* e_selection_model_parent_class->destroy) (object);
 }
 
 static void
@@ -511,9 +514,11 @@ e_selection_model_key_press      (ESelectionModel *selection,
 {
 	switch (key->keyval) {
 	case GDK_Up:
+	case GDK_KP_Up:
 		return move_selection(selection, TRUE, key->state);
 		break;
 	case GDK_Down:
+	case GDK_KP_Down:
 		return move_selection(selection, FALSE, key->state);
 		break;
 	case GDK_space:
